==> nmrium-0.50.1.tgz: package/lib/component/reducer/preferences/actions/matrixGeneration.js <==
import { v4 } from '@lukeed/uuid';
import { getActiveWorkspace } from '../utilities/getActiveWorkspace';
function addExclusionZone(draft, action) {
    const { zone, range, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.formatting.panels;
    const exclusionZone = {
        id: v4(),
        ...zone,
    };
    if (!panels.matrixGeneration?.[nucleus]) {
        const options = {
            exclusionsZones: [exclusionZone],
            filters: [],
            range,
            numberOfPoints: 1024,
        };
        panels.matrixGeneration = {
            ...panels.matrixGeneration,
            [nucleus]: options,
        };
    }
    else {
        panels.matrixGeneration[nucleus].exclusionsZones.push(exclusionZone);
    }
}
function deleteExclusionZone(draft, action) {
    const { zone, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.formatting.panels;
    if (panels.matrixGeneration?.[nucleus]) {
        const options = panels.matrixGeneration[nucleus];
        options.exclusionsZones = options.exclusionsZones.filter((_zone) => _zone.id !== zone.id);
    }
}
function setMatrixGenerationOptions(draft, action) {
    const { options, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.formatting.panels;
    panels.matrixGeneration = { ...panels.matrixGeneration, [nucleus]: options };
}
export { addExclusionZone, deleteExclusionZone, setMatrixGenerationOptions };

==> nmrium-0.55.0.tgz: package/lib/component/reducer/preferences/actions/matrixGeneration.js <==
import { v4 } from '@lukeed/uuid';
import { getActiveWorkspace } from '../utilities/getActiveWorkspace';
function addExclusionZone(draft, action) {
    const { zone, range, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.panels;
    const exclusionZone = {
        id: v4(),
        ...zone,
    };
    if (!panels.matrixGeneration?.[nucleus]) {
        const options = {
            exclusionsZones: [exclusionZone],
            filters: [],
            range,
            numberOfPoints: 1024,
        };
        panels.matrixGeneration = {
            ...panels.matrixGeneration,
            [nucleus]: options,
        };
    }
    else {
        panels.matrixGeneration[nucleus].exclusionsZones.push(exclusionZone);
    }
}
function deleteExclusionZone(draft, action) {
    const { zone, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.panels;
    if (panels.matrixGeneration?.[nucleus]) {
        const options = panels.matrixGeneration[nucleus];
        options.exclusionsZones = options.exclusionsZones.filter((_zone) => _zone.id !== zone.id);
    }
}
function setMatrixGenerationOptions(draft, action) {
    const { options, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.panels;
    panels.matrixGeneration = { ...panels.matrixGeneration, [nucleus]: options };
}
export { addExclusionZone, deleteExclusionZone, setMatrixGenerationOptions };
